/*******************************************************************************
 * Class for representing bank accounts
 * @author    Tomáš Pitner
 * @version   0.9
 */
public class Account implements Informing {
    
    // this initialization will be done just once(!)
    // when the class is used for the first time
    private static int accountCount = 0;

    private Person owner;
    private int balance;
    
    /**
     * Creates a new account with a non-null owner Person
     * @param owner must not be null
     * @throws NullPointerException if owner is null
     */
    public Account(Person owner) {
        this(owner, 0);
    }
    
    public Account(Person owner, int initialBalance) {
        if(owner == null) {
            throw new NullPointerException();
        }
        this.owner = owner;
        this.balance = initialBalance;
        accountCount++;
    }
    
    public Person getOwner() {
        return owner;
    }
    
    public static void printAccountCount() {
        System.out.println("The bank has "+accountCount+" account(s)");
    }
    
    public int getBalance() {
        return balance;
    }
    
    public boolean add(int amount) {
        balance += amount;
        return true;
    }
    
    public void transferTo(Account target, int amount) {
        if(target == null) {
            throw new NullPointerException();
        }
        if(amount <= 0) {
            throw new IllegalArgumentException();
        }
        if(this.add(-amount)) {
            target.add(amount);
        }
    }
    
    public void info() {
        System.out.println("Account owner=" + owner
            + " balance=" + getBalance());
    }

    public void writeInfo() {
        info();
    }
}
